package com.nisum.splitmerchantpayment.repository;

import com.nisum.splitmerchantpayment.entity.Size;
import com.nisum.splitmerchantpayment.exception.SizeTypeNotAvailableException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

/**
 * This is a customized repository with updateProduct that helps to update
 * product irrespective of different product properties
 */
@Repository
public class BaseRepository {
    @PersistenceContext
    private EntityManager getEntityManger;
    @Autowired
    private ProductRepository productRepo;

    /**
     * This method will updates product table irrespective of different columns
     * @param columnName
     * @param id
     * @param quantity
     * @return
     */
    public int updateProduct(String columnName, String id, Integer quantity) {
        Integer orginalQuantity = getQuantity(columnName, id) - quantity;
        return getEntityManger.createQuery("update Product set " + columnName + "= :quantity where productId=:id")
                .setParameter("quantity", orginalQuantity)
                .setParameter("id", id)
                .executeUpdate();
    }

    /**
     * This helps to give product quantity irrespective of different sizes
     * @param columnName
     * @param id
     * @return
     */
    private Integer getQuantity(String columnName, String id) {
        Size size = productRepo.findById(id).get().getSize();
        Integer quantity = 0;
        switch (columnName) {
            case "s":
                quantity = size.getS();
                break;
            case "m":
                quantity = size.getM();
                break;
            case "l":
                quantity = size.getL();
                break;
            case "xl":
                quantity = size.getXl();
                break;
            case "xxl":
                quantity = size.getXxl();
                break;
            default:
                throw new SizeTypeNotAvailableException("Product not available for the size ");
        }
        return quantity;
    }
}