package com.nisum.splitmerchantpayment.service;

import com.nisum.splitmerchantpayment.entity.CartProduct;
import com.nisum.splitmerchantpayment.entity.OrderDao;
import com.nisum.splitmerchantpayment.entity.Product;
import com.nisum.splitmerchantpayment.model.ProductToCartDto;

import java.util.List;

/**
 * UserService is an Interface.
 * It's providing five features to implement user operations
 * Those are : getProductById(String productId)
 *             checkAvailability(ProductToCartDto productToCartDto)
 *             addToCart(ProductToCartDto productToCartDto)
 *             getCartList(String customerPhoneNumber)
 *             placeOrder(String customerPhoneNumber, Double amount)
 *             getOrdersByCustomer(String customerPhoneNumber)
 */
public interface UserService {
    /**
     * getProductById  method helpful to find by productId
     * @param productId
     * @return
     */
    public Product getProductById(String productId);
    /**
     * checkAvailability will check quantity which all existed in database to user required quantity.
     * @param productToCartDto
     * @return
     */
    public Product checkAvailability(ProductToCartDto productToCartDto);
    /**
     * addToCart method is helpful to add product to cart
     * and condition checks will be done here before adding to the cart
     * @param productToCartDto
     * @return String
     */
    public String addToCart(ProductToCartDto productToCartDto);

    /**
     * getCartList method helpful to get cart list what all products customer ordered previously
     * @param customerPhoneNumber
     * @return
     */
    public List<CartProduct> getCartList(String customerPhoneNumber);

    /**
     * placeOrder is helpful to place order what all products added to cart, and it returns order details.
     * @param customerPhoneNumber
     * @param amount
     * @return
     */

    public OrderDao placeOrder(String customerPhoneNumber, Double amount);

    /**
     * getOrdersByCustomer method helpful to get Ordered history of customer by id,
     * and it returns order history of specific customer
     * @param customerPhoneNumber
     * @return
     */

    public List<OrderDao> getOrdersByCustomer(String customerPhoneNumber);

    /**
     * getOrdersByCustomer method helpful to get Ordered history of customer by id and order id,
     * and it returns order history of  customer to specific order id
     * @param customerPhoneNumber
     * @param orderId
     * @return
     */
    public OrderDao getOrderByCustomerIdAndOrderId(String customerPhoneNumber, String orderId);
}